﻿using System;
using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Media.Animation;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 탐색 전이 정보
        /// </summary>
        private NavigationTransitionInfo navigationTransitionInfo = null;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "Frame 클래스 : 페이지 전이 사용하기";

            #endregion

            this.frame.Navigate(typeof(SamplePage1));
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 전이 라디오 버튼 체크시 처리하기 - transitionRadioButton_Checked(sender, e)

        /// <summary>
        /// 전이 라디오 버튼 체크시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void transitionRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            RadioButton radioButton = sender as RadioButton;

            string transitionMode = radioButton.Content.ToString();

            if(transitionMode != "디폴트")
            {
                if(transitionMode == "입장")
                {
                    this.navigationTransitionInfo = new EntranceNavigationTransitionInfo();
                }
                else if(transitionMode == "드릴인")
                {
                    this.navigationTransitionInfo = new DrillInNavigationTransitionInfo();
                }
                else if(transitionMode == "서프레스")
                {
                    this.navigationTransitionInfo = new SuppressNavigationTransitionInfo();
                }
                else if(transitionMode == "오른쪽 슬라이드")
                {
                    this.navigationTransitionInfo = new SlideNavigationTransitionInfo() { Effect = SlideNavigationTransitionEffect.FromRight };
                }
                else if(transitionMode == "왼쪽 슬라이드")
                {
                    this.navigationTransitionInfo = new SlideNavigationTransitionInfo() { Effect = SlideNavigationTransitionEffect.FromLeft };
                }
            }
            else
            {
                this.navigationTransitionInfo = null;
            }
        }

        #endregion
        #region 이동하기 버튼 클릭시 처리하기 - forwardButton_Click(sender, e)

        /// <summary>
        /// 이동하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void forwardButton_Click(object sender, RoutedEventArgs e)
        {
            Type targetType = this.frame.BackStackDepth % 2 == 1 ? typeof(SamplePage1) : typeof(SamplePage2);

            if(this.navigationTransitionInfo == null)
            {
                this.frame.Navigate(targetType, null);
            }
            else
            {
                this.frame.Navigate(targetType, null, this.navigationTransitionInfo);
            }
        }

        #endregion
        #region 돌아가기 버튼 클릭시 처리하기 - backwardButton_Click(sender, e)

        /// <summary>
        /// 돌아가기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void backwardButton_Click(object sender, RoutedEventArgs e)
        {
            if(this.frame.BackStackDepth > 0)
            {
                this.frame.GoBack();
            }
        }

        #endregion
    }
}